DataModelType

Enum DataModelType 

pub enum DataModelType {
Show 26 variants Bool, I8, U8, I16, I32, I64, I128, U16, U32, U64, U128, Usize, Isize, F32, F64, Char, String, ByteArray, Option(&'static Self), Unit, Seq(&'static Self), Tuple(&'static [&'static Self]), Map { key: &'static Self, val: &'static Self, }, Struct { name: &'static str, data: Data, }, Enum { name: &'static str, variants: &'static [&'static Variant], }, Schema,
}
This enum lists which of the Data Model Types apply to a given type. This describes how the type is encoded on the wire.

This enum contains all Serde Data Model types as well as a “Schema” Type, which corresponds to DataModelType itself.

Variants



Bool

The bool Serde Data Model Type



I8

The i8 Serde Data Model Type



U8

The u8 Serde Data Model Type



I16

A variably encoded i16



I32

A variably encoded i32



I64

A variably encoded i64



I128

A variably encoded i128



U16

A variably encoded u16



U32

A variably encoded u32



U64

A variably encoded u64



U128

A variably encoded u128



Usize

A variably encoded usize



Isize

A variably encoded isize



F32

The f32 Serde Data Model Type



F64

The f64 Serde Data Model Type



Char

The char Serde Data Model Type



String

The String Serde Data Model Type



ByteArray

The &[u8] Serde Data Model Type



Option(&'static Self)

The Option<T> Serde Data Model Type



Unit

The () Serde Data Model Type



Seq(&'static Self)

The “Sequence” Serde Data Model Type



Tuple(&'static [&'static Self])

The “Tuple” Serde Data Model Type



Map

The “Map” Serde Data Model Type

Fields

key: &'static Self

The map “Key” type

val: &'static Self

The map “Value” type



Struct

One of the struct Serde Data Model types

Fields

name: &'static str

The name of this struct

data: Data

The data contained in this struct



Enum

The “Enum” Serde Data Model Type (which contains any of the “Variant” types)

Fields

name: &'static str

The name of this struct

variants: &'static [&'static Variant]

The variants contained in this enum



Schema